@@ -1,22 +1,26 @@
 package Search::OpenSearch::Result;
-use Moose;
+use strict;
+use warnings;
 use JSON;
+use base qw( Rose::ObjectX::CAF );
 use overload
     '""'     => sub { $_[0]->stringify; },
     'bool'   => sub {1},
     fallback => 1;
 
-use namespace::sweep;
+our $VERSION = '0.15';
 
-our $VERSION = '0.299_03';
-
-has 'build_time'  => ( is => 'rw' );
-has 'search_time' => ( is => 'rw' );
-has 'doc'         => ( is => 'rw' );
-has 'code'        => ( is => 'rw' );
-has 'success'     => ( is => 'rw' );
-has 'msg'         => ( is => 'rw' );
-has 'total'       => ( is => 'rw' );
+__PACKAGE__->mk_accessors(
+    qw(
+        build_time
+        search_time
+        doc
+        code
+        success
+        msg
+        total
+        )
+);
 
 sub stringify {
     my $self = shift;
